unit mpsurl;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs, ShellAPI;

type
  TMPSURLType = (mpsFile, mpsFtp, mpsGopher, mpsHttp, mpsHttps, mpsMailto, mpsNews, mpsTelnet, mpsWais);

  TMPSURL = class(TComponent)
  private
    FURL: string;
    FURLType: TMPSURLType;

    procedure SeTMPSURL(value: string);
    procedure SeTMPSURLType(value: TMPSURLType);
  protected

  public
    constructor Create(AOwner: TComponent); override;
    function Execute: boolean;
  published
    property URL: string read FURL write SeTMPSURL;
    property URLType: TMPSURLType read FURLType write SeTMPSURLType default mpsHttp;
  end;

procedure Register;

implementation

function ExecmpseFile(const FileName, Params, DefaultDir: string; ShowCmd: Integer): THandle;
var
  zFileName, zParams, zDir: array[0..79] of Char;
begin
  Result := ShellExecute(Application.MainForm.Handle, nil, StrPCopy(zFileName, FileName),
                         StrPCopy(zParams, Params), StrPCopy(zDir, DefaultDir), ShowCmd);
end;

function TMPSURL.Execute: boolean;
var
  HyperlinkType, URLString: string;
begin
  result := false;
  if FURL <> '' then
  begin
    case FURLType of
      mpsFile   : HyperlinkType := 'file://';
      mpsFtp    : HyperlinkType := 'ftp://';
      mpsGopher : HyperlinkType := 'gopher://';
      mpsHttp   : HyperlinkType := 'http://';
      mpsHttps  : HyperlinkType := 'https://';
      mpsMailto : HyperlinkType := 'mailto:';
      mpsNews   : HyperlinkType := 'news:';
      mpsTelnet : HyperlinkType := 'telnet:';
      mpsWais   : HyperlinkType := 'wais:';
    end;
    URLString := HyperlinkType + FURL;
    result := (ExecmpseFile(URLString, '', '', SW_SHOWNOACTIVATE) > 32);
  end;
end;

procedure TMPSURL.SeTMPSURL(value: string);
begin
  if value <> FURL then
     FURL := value;
end;

procedure TMPSURL.SeTMPSURLType(value: TMPSURLType);
begin
  if value <> FURLType then
     FURLType := value;
end;

constructor TMPSURL.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FURLType := mpsHttp;
  FURL := '';
end;

procedure Register;
begin
  RegisterComponents('MP Software', [TMPSURL]);
end;

end.
